%bcond_with tests

Name:           python-virtualenv
Version:        20.21.1
Release:        7%{?dist}
Summary:        Tool to create isolated Python environments

License:        MIT
URL:            http://pypi.python.org/pypi/virtualenv
Source0:        %{pypi_source virtualenv}

# Add /usr/share/python-wheels to extra_search_dir
Patch1:         rpm-wheels.patch

## Backports from virtualenv 20.22+
## We cannot update yet as we want to preserve support for Python 2.7 and 3.6 environments
## Patches in https://github.com/fedora-python/virtualenv/commits/20.21.x
# (20.23.0) prevent PermissionError when using venv creator on some systems
# https://github.com/pypa/virtualenv/pull/2543
Patch2:         prevent-PermissionError-when-using-venv-creator-on-s.patch
# (20.23.0) 3.12 support and no setuptools/wheel on 3.12+
# freezgun and typing changes stripped
# files missing in sdist removed from the path file
# https://github.com/pypa/virtualenv/pull/2558
Patch3:         3.12-support-and-no-setuptools-wheel-on-3.12-2558.patch
# (20.24.0) Fix tests with pluggy 1.2.0+
# Manually cherry-picked from https://github.com/pypa/virtualenv/pull/2593
Patch4:         Fix-tests-with-pluggy-1.2.0.patch
# Fix compatibility with Python 3.13
# https://github.com/pypa/virtualenv/pull/2673
Patch5:         py3.13.patch

BuildArch:      noarch

BuildRequires:  python%{python3_pkgversion}-devel


%if %{with tests}
BuildRequires:  fish
BuildRequires:  tcsh
BuildRequires:  gcc
BuildRequires:  python%{python3_pkgversion}-flaky
BuildRequires:  python%{python3_pkgversion}-packaging
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-pytest-mock
BuildRequires:  python%{python3_pkgversion}-pytest-randomly
BuildRequires:  python%{python3_pkgversion}-pytest-timeout

# The .dist-info folder generated by
# %%pyproject_buildrequires confuses
# importlib.metadata entry points and
# that leads to failed tests where
# virtualenv is run via subprocess.
# The .dist-info is removed since:
BuildRequires:  pyproject-rpm-macros >= 1.6.3
%endif

# RPM installed wheels
BuildRequires:  %{python_wheel_pkg_prefix}-pip-wheel
BuildRequires:  %{python_wheel_pkg_prefix}-setuptools-wheel
BuildRequires:  %{python_wheel_pkg_prefix}-wheel-wheel

%description
virtualenv is a tool to create isolated Python environments. virtualenv
is a successor to workingenv, and an extension of virtual-python. It is
written by Ian Bicking, and sponsored by the Open Planning Project. It is
licensed under an MIT-style permissive license.


%package -n     python%{python3_pkgversion}-virtualenv
Summary:        Tool to create isolated Python environments

# This virtualenv requires the "venv" install scheme on Pythons
# where we patch "posix_prefix".
# Explicitly conflict with Pythons where we don't have it yet.
Conflicts:      python3.11 < 3.11.0~a2
%if 0%{?fedora} >= 36
Conflicts:      python3.10 < 3.10.0-3
%endif

Obsoletes:      python%{python3_pkgversion}-virtualenv-python26 < 16.6
%{?python_provide:%python_provide python%{python3_pkgversion}-virtualenv}

# Provide "virtualenv" for convenience
Provides:       virtualenv = %{version}-%{release}

# RPM installed wheels
Requires:       %{python_wheel_pkg_prefix}-pip-wheel
Requires:       %{python_wheel_pkg_prefix}-setuptools-wheel
Requires:       %{python_wheel_pkg_prefix}-wheel-wheel
# Pythons < 3.7 need an older version of wheel:
Requires:       (%{python_wheel_pkg_prefix}-wheel0.37-wheel if python2.7)
Requires:       (%{python_wheel_pkg_prefix}-wheel0.37-wheel if pypy2.7)
Requires:       (%{python_wheel_pkg_prefix}-wheel0.37-wheel if python3.6)

%description -n python%{python3_pkgversion}-virtualenv
virtualenv is a tool to create isolated Python environments. virtualenv
is a successor to workingenv, and an extension of virtual-python. It is
written by Ian Bicking, and sponsored by the Open Planning Project. It is
licensed under an MIT-style permissive license


%prep
%autosetup -p1 -n virtualenv-%{version}

# Remove the wheels provided by RPM packages
rm src/virtualenv/seed/wheels/embed/pip-*
rm src/virtualenv/seed/wheels/embed/setuptools-*
rm src/virtualenv/seed/wheels/embed/wheel-*

test ! -f src/virtualenv/seed/embed/wheels/*.whl

# Replace hardcoded path from rpm-wheels.patch by %%{python_wheel_dir}
# On Fedora, this should change nothing, but when building for RHEL9+, it will
sed -i "s|/usr/share/python-wheels|%{python_wheel_dir}|" src/virtualenv/util/path/_system_wheels.py

# Allow platformdirs version 4
# Backported from release 20.24.7
# https://github.com/pypa/virtualenv/commit/55650340d9c9415bf035596266f245a8d59c6993
sed -i "s/platformdirs<4/platformdirs<5/" pyproject.toml

%if 0%{?rhel} >= 9
%generate_buildrequires
%pyproject_buildrequires
%endif

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files virtualenv

%if %{with tests}
%check
# Skip tests which requires internet or some extra dependencies
# Requires internet:
# - test_download_*
# - test_can_build_c_extensions (on Python 3.12+)
# Uses disabled functionalities around bundled wheels:
# - test_wheel_*
# - test_seed_link_via_app_data
# - test_base_bootstrap_via_pip_invoke
# - test_acquire.py (whole file)
# - test_bundle.py (whole file)
# Uses disabled functionalities around automatic updates:
# - test_periodic_update.py (whole file)
# Requires Python 2:
# - test_py_pyc_missing
PIP_CERT=/etc/pki/tls/certs/ca-bundle.crt \
%pytest -vv -k "not test_bundle and \
                not test_acquire and \
                not test_periodic_update and \
                not test_wheel_ and \
                not test_download_ and \
%if v"%{python3_version}" >= v"3.12"
                not test_can_build_c_extensions and \
%endif
                not test_base_bootstrap_via_pip_invoke and \
                not test_seed_link_via_app_data and \
                not test_py_pyc_missing"
%endif

%files -n python%{python3_pkgversion}-virtualenv -f %{pyproject_files}
%doc README.md
%{_bindir}/virtualenv

%changelog
* Mon Dec 04 2023 Lumír Balhar <lbalhar@redhat.com> - 20.21.1-7
- Fix compatibility with Python 3.13
Resolves: rhbz#2251781

* Thu Nov 23 2023 Lumír Balhar <lbalhar@redhat.com> - 20.21.1-6
- Allow platformdirs version 4

* Wed Aug 30 2023 Miro Hrončok <mhroncok@redhat.com> - 20.21.1-5
- Fix tests with pluggy 1.2.0+

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 20.21.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jun 29 2023 Python Maint <python-maint@redhat.com> - 20.21.1-3
- Rebuilt for Python 3.12

* Tue Jun 13 2023 Python Maint <python-maint@redhat.com> - 20.21.1-2
- Bootstrap for Python 3.12

* Fri Apr 28 2023 Miro Hrončok <mhroncok@redhat.com> - 20.21.1-1
- Update to 20.21.1
- Backport from 20.23.0: Don't install setuptools and wheel to Python 3.12+ environments

* Mon Mar 13 2023 Lumír Balhar <lbalhar@redhat.com> - 20.21.0-1
- Update to 20.21.0 (rhbz#2177543)

* Mon Mar 06 2023 Miro Hrončok <mhroncok@redhat.com> - 20.20.0-2
- Fix build with pyproject-rpm-macros >= 1.6.3
- Local workaround collided with the fix there

* Wed Mar 01 2023 Lumír Balhar <lbalhar@redhat.com> - 20.20.0-1
- Update to 20.20.0 (rhbz#2174221)

* Thu Feb 09 2023 Lumír Balhar <lbalhar@redhat.com> - 20.19.0-1
- Update to 20.19.0 (rhbz#2167499)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 20.17.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Dec 12 2022 Miro Hrončok <mhroncok@redhat.com> - 20.17.1-2
- Require python-wheel0.37-wheel for older Pythons

* Wed Dec 07 2022 Lumír Balhar <lbalhar@redhat.com> - 20.17.1-1
- Update to 20.17.1 (rhbz#2151044)

* Thu Dec 01 2022 Lumír Balhar <lbalhar@redhat.com> - 20.17.0-1
- Update to 20.17.0 (rhbz#2148907)

* Mon Nov 14 2022 Lumír Balhar <lbalhar@redhat.com> - 20.16.7-1
- Update to 20.16.7 (#2142311)

* Thu Oct 27 2022 Lumír Balhar <lbalhar@redhat.com> - 20.16.6-1
- Update to 20.16.6
Resolves: rhbz#2137713

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 20.15.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jun 29 2022 Lumír Balhar <lbalhar@redhat.com> - 20.15.1-1
- Update to 20.15.1
Resolves: rhbz#2101975

* Sun Jun 26 2022 Lumír Balhar <lbalhar@redhat.com> - 20.15.0-1
- Update to 20.15.0
Resolves: rhbz#2101126

* Tue Jun 14 2022 Python Maint <python-maint@redhat.com> - 20.13.4-4
- Rebuilt for Python 3.11

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 20.13.4-3
- Bootstrap for Python 3.11

* Mon Jun 06 2022 Lumír Balhar <lbalhar@redhat.com> - 20.13.4-2
- Improve compatibility with Python 3.11
Resolves: rhbz#2093193

* Mon Mar 21 2022 Lumír Balhar <lbalhar@redhat.com> - 20.13.4-1
- Update to 20.13.4
Resolves: rhbz#2065839

* Mon Mar 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 20.13.3-3
- BR tcsh so we can test csh activation scripts

* Mon Mar 14 2022 Lumír Balhar <lbalhar@redhat.com> - 20.13.3-2
- Add explicit error when embed version of wheels is requested
Resolves: rhbz#2053948

* Tue Mar 08 2022 Lumír Balhar <lbalhar@redhat.com> - 20.13.3-1
- Update to 20.13.3
Resolves: rhbz#2061449

* Fri Feb 25 2022 Lumír Balhar <lbalhar@redhat.com> - 20.13.2-1
- Update to 20.13.2
Resolves: rhbz#2058146

* Sun Feb 06 2022 Lumír Balhar <lbalhar@redhat.com> - 20.13.1-1
- Update to 20.13.1
Resolves: rhbz#2051025

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 20.13.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Mon Jan 03 2022 Lumír Balhar <lbalhar@redhat.com> - 20.13.0-1
- Update to 20.13.0
Resolves: rhbz#2035895

* Mon Nov 08 2021 Lumír Balhar <lbalhar@redhat.com> - 20.10.0-2
- Remove hack for local/ prefixes

* Tue Nov 02 2021 Lumír Balhar <lbalhar@redhat.com> - 20.10.0-1
- Update to 20.10.0
Resolves: rhbz#2019116

* Mon Oct 25 2021 Lumír Balhar <lbalhar@redhat.com> - 20.9.0-1
- Update to 20.9.0
Resolves: rhbz#2016758

* Wed Oct 06 2021 Lumír Balhar <lbalhar@redhat.com> - 20.8.1-1
- Update to 20.8.1
Resoves: rhbz#2007595

* Wed Oct 06 2021 Miro Hrončok <mhroncok@redhat.com> - 20.7.2-2
- Remove /local/ part from virtualenv paths
Resolves: rhbz#2011455

* Mon Aug 16 2021 Lumír Balhar <lbalhar@redhat.com> - 20.7.2-1
- Update to 20.7.2
Resolves: rhbz#1991618

* Sun Aug 01 2021 Lumír Balhar <lbalhar@redhat.com> - 20.7.0-1
- Update to 20.7.0
Resolves: rhbz#1988721

* Wed Jul 21 2021 Lumír Balhar <lbalhar@redhat.com> - 20.6.0-1
- Update to 20.6.0
Resolves: rhbz#1981792

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 20.4.7-3
- Rebuilt for Python 3.10

* Wed Jun 02 2021 Python Maint <python-maint@redhat.com> - 20.4.7-2
- Bootstrap for Python 3.10

* Tue May 25 2021 Lumír Balhar <lbalhar@redhat.com> - 20.4.7-1
- Update to 20.4.7
Resolves: rhbz#1964115

* Wed Apr 21 2021 Lumír Balhar <lbalhar@redhat.com> - 20.4.4-1
- Update to 20.4.4
  Resolves: rhbz#1951515

* Wed Mar 17 2021 Lumír Balhar <lbalhar@redhat.com> - 20.4.3-1
- Update to 20.4.3
Resolves: rhbz#1939428

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 20.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Jan 19 2021 Lumír Balhar <lbalhar@redhat.com> - 20.4.0-1
- Update to 20.4.0 (#1915682)

* Tue Jan 12 2021 Lumír Balhar <lbalhar@redhat.com> - 20.3.0-1
- Update to 20.3.0 (#1914641)

* Mon Nov 23 2020 Lumír Balhar <lbalhar@redhat.com> - 20.2.1-1
- Update to 20.2.1 (#1900253)

* Wed Nov 18 2020 Lumír Balhar <lbalhar@redhat.com> - 20.1.0-1
- Update to 20.1.0 (#1891297)

* Fri Oct 02 2020 Lumír Balhar <lbalhar@redhat.com> - 20.0.32-1
- Update to 20.0.32 (#1884449)

* Thu Sep 03 2020 Lumír Balhar <lbalhar@redhat.com> - 20.0.31-1
- Update to 20.0.31 (#1869352)

* Thu Aug 06 2020 Lumír Balhar <lbalhar@redhat.com> - 20.0.30-1
- Update to 20.0.30 (#1862562)

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 20.0.28-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Fri Jul 24 2020 Miro Hrončok <mhroncok@redhat.com> - 20.0.28-1
- Update to 20.0.28
- Fixes rhbz#1860272

* Thu Jul 23 2020 Lumír Balhar <lbalhar@redhat.com> - 20.0.27-1
- Update to 20.0.27 (#1854551)

* Tue Jun 23 2020 Lumír Balhar <lbalhar@redhat.com> - 20.0.25-1
- Update to 20.0.25

* Mon Jun 15 2020 Lumír Balhar <lbalhar@redhat.com> - 20.0.23-1
- Update to 20.0.23 (#1742034)

* Sat May 23 2020 Miro Hrončok <mhroncok@redhat.com> - 16.7.10-2
- Rebuilt for Python 3.9

* Tue Feb 25 2020 Miro Hrončok <mhroncok@redhat.com> - 16.7.10-1
- Update to 16.7.10
- Explicitly require setuptools < 44 with Python 3.4

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 16.7.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Sep 03 2019 Miro Hrončok <mhroncok@redhat.com> - 16.7.3-2
- Prefer wheels bundled in Python's ensurepip module over the RPM built ones
- This allows continuing support for Python 3.4 in Fedora 32+

* Wed Aug 21 2019 Charalampos Stratakis <cstratak@redhat.com> - 16.7.3-1
- Update to 16.7.3 (#1742034)

* Fri Aug 16 2019 Miro Hrončok <mhroncok@redhat.com> - 16.6.1-3
- Rebuilt for Python 3.8

* Mon Jul 29 2019 Miro Hrončok <mhroncok@redhat.com> - 16.6.1-2
- Drop python2-virtualenv

* Thu Jul 11 2019 Miro Hrončok <mhroncok@redhat.com> - 16.6.1-1
- Update to 16.6.1 (#1699031)
- No more Python 2.6 or Jython support
- Drop runtime dependency on pythonX-devel

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 16.0.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Dec 13 2018 Miro Hrončok <mhroncok@redhat.com> - 16.0.0-6
- Don't fail on missing certifi's cert bundle (#1655253)

* Wed Aug 15 2018 Miro Hrončok <mhroncok@redhat.com> - 16.0.0-5
- Use wheels from RPM packages
- Put wheels needed for Python 2.6 into a subpackage
- Only have one /usr/bin/virtualenv (#1599422)
- Provide "virtualenv" (#1502670)

* Wed Jul 18 2018 Miro Hrončok <mhroncok@redhat.com> - 16.0.0-4
- Reintroduce support for Python 2.6 (#1602347)
- Add missing bundled provides

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 16.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sat Jun 16 2018 Miro Hrončok <mhroncok@redhat.com> - 16.0.0-2
- Rebuilt for Python 3.7

* Thu May 17 2018 Steve Milner <smilner@redhat.com> - 16.0.0-1
- Updated for upstream release.

* Wed Feb 28 2018 Iryna Shcherbina <ishcherb@redhat.com> - 15.1.0-5
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 15.1.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Sep 29 2017 Troy Dawson <tdawson@redhat.com> - 15.1.0-3
- Cleanup spec file conditionals

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 15.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jun 12 2017 Steve Milner <smilner@redhat.com> - 15.1.0-1
- Update to 15.1.0 per https://bugzilla.redhat.com/show_bug.cgi?id=1454962

* Fri Feb 17 2017 Michal Cyprian <mcyprian@redhat.com> - 15.0.3-6
- Check if exec_dir exists before listing it's content during venv create process

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 15.0.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Jan  4 2017 Steve Milner <smilner@redhat.com> - 15.0.3-4
- Updated version binaries per discussion at bz#1385240.

* Tue Dec 13 2016 Stratakis Charalampos <cstratak@redhat.com> - 15.0.3-3
- Rebuild for Python 3.6

* Mon Oct 17 2016 Steve Milner <smilner@redhat.com> - 15.0.3-2
- Added MAJOR symlinks per bz#1385240.

* Mon Aug  8 2016 Steve Milner <smilner@redhat.com> - 15.0.3-1
- Update for upstream release.

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 14.0.6-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Sun Feb 21 2016 Orion Poplawski <orion@cora.nwra.com> - 14.0.6-1
- Update to 14.0.6

* Tue Feb 2 2016 Orion Poplawski <orion@cora.nwra.com> - 13.1.2-4
- Modernize spec
- Fix python3 package file ownership

* Wed Dec 2 2015 Orion Poplawski <orion@cora.nwra.com> - 13.1.2-3
- Move documentation to separate package (bug #1219139)

* Wed Oct 14 2015 Robert Kuska <rkuska@redhat.com> - 13.1.2-2
- Rebuilt for Python3.5 rebuild

* Mon Aug 24 2015 Steve Milner <smilner@redhat.com> - 13.1.2-1
- Update for upstream release.

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 12.0.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Mar 16 2015 Matej Stuchlik <mstuchli@redhat.com> - 12.0.7-1
- Update to 12.0.7

* Thu Jan 15 2015 Matthias Runge <mrunge@redhat.com> - 1.11.6-2
- add a python3-package, thanks to Matej Stuchlik (rhbz#1179150)

* Wed Jul 09 2014 Matthias Runge <mrunge@redhat.com> - 1.11.6-1
- update to 1.11.6:
  Upstream updated setuptools to 3.6, updated pip to 1.5.6

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Aug 15 2013 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.10.1-1
- Upstream upgraded pip to v1.4.1
- Upstream upgraded setuptools to v0.9.8 (fixes CVE-2013-1633)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue May 14 2013 Toshio Kuratomi <toshio@fedoraproject.org> - 1.9.1-1
- Update to upstream 1.9.1 because of security issues with the bundled
  python-pip in older releases.  This is just a quick fix until a
  python-virtualenv maintainer can unbundle the python-pip package
  see: https://bugzilla.redhat.com/show_bug.cgi?id=749378

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Aug 14 2012 Steve Milner <me@stevemilner.org> - 1.7.2-1
- Update for upstream bug fixes.
- Added path for versioned binary.
- Patch no longer required.

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.1.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Mar 14 2012 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.7.1.2-1
- Update for upstream bug fixes.
- Added patch for sphinx building

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Dec 20 2011 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.7-1
- Update for https://bugzilla.redhat.com/show_bug.cgi?id=769067

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Oct 16 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.5.1-1
- Added _weakrefset requirement for Python 2.7.1.
- Add support for PyPy.
- Uses a proper temporary dir when installing environment requirements.
- Add --prompt option to be able to override the default prompt prefix.
- Add fish and csh activate scripts.

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 1.4.8-4
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Wed Jul  7 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.4.8-3
- Fixed EPEL installation issue from BZ#611536

* Wed Jun  9 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.4.8-2
- Only replace the python shebang on the first line (Robert Buchholz)

* Wed Apr 28 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.4.8-1
- update pip to 0.7
- move regen-docs into bin/
- Fix #31, make activate_this.py work on Windows (use Lib/site-packages)
unset PYTHONHOME envioronment variable -- first step towards fixing the PYTHONHOME issue; see e.g. https://bugs.launchpad.net/virtualenv/+bug/290844
- unset PYTHONHOME in the (Unix) activate script (and reset it in deactivate())
- use the activate.sh in virtualenv.py via running bin/rebuild-script.py
- add warning message if PYTHONHOME is set

* Fri Apr 2 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.4.6-1
- allow script creation without setuptools
- fix problem with --relocate when bin/ has subdirs (fixes #12)
- Allow more flexible .pth file fixup
- make nt a required module, along with posix. it may not be a builtin module on jython
- don't mess with PEP 302-supplied __file__, from CPython, and merge in a small startup optimization for Jython, from Jython

* Tue Dec 22 2009 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.4.3-1
- Updated for upstream release.

* Thu Nov 12 2009 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.4.2-1
- Updated for upstream release.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Apr 28 2009 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.3.3-1
- Updated for upstream release.

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Dec 25 2008 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.3.2-1
- Updated for upstream release.

* Thu Dec 04 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.3.1-4
- Rebuild for Python 2.6

* Mon Dec  1 2008 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.3.1-3
- Added missing dependencies.

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.3.1-2
- Rebuild for Python 2.6

* Fri Nov 28 2008 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.3.1-1
- Updated for upstream release

* Sun Sep 28 2008 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.3-1
- Updated for upstream release

* Sat Aug 30 2008 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2-1
- Updated for upstream release

* Fri Aug 29 2008 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.1-3
- Updated from review notes

* Thu Aug 28 2008 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.1-2
- Updated from review notes

* Tue Aug 26 2008 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.1-1
- Initial Version
